# Paperclip WebMerge

This gem allows you to save [Paperclip](https://github.com/thoughtbot/paperclip) files on [WebMerge](https://www.webmerge.me/)


## Installation

Add this line to your application's Gemfile. Bundle, then restart your server.

```ruby
gem 'paperclip-webmerge'
```
Migrate your model to have a `web_merge_id` integer attribute. When Paperclip saves your file, it will reference the document id on WebMerge with this attribute.

```
rails g migration add_web_merge_id_to_your_model web_merge_id:integer
rake db:migrate
```


## Setup

Example:

Add paperclip to your model, specifiying `:web_merge` as the storage adapter.

```ruby
class User
  has_attached_file :document, storage: :web_merge, web_merge_credentials: Rails.root.join('config/web_merge.yml')
  ...
end
```
Add WebMerge your API credentials. You can get your credentials under "Api Access" over at [WebMerge](https://www.webmerge.me/)

```
# config/web_merge.yml

api_key: <%= ENV["WEB_MERGE_API_KEY"] %>,
api_secret: <%= ENV["WEB_MERGE_API_SECRET"] %>
```

You are fully setup. Your files now sync up with WebMerge!


## Usage

### The `:web_merge_credentials` option

```ruby
:web_merge_credentials => Rails.root.join("config/web_merge.yml")
# or
:web_merge_credentials => {api_key: "foo", api_secret: "bar"}
```

For the list of required credentials, take a look at the `config/web_merge.yml`
above.

The YAML file supports ERB:

```
api_key: <%= ENV["WEB_MERGE_API_KEY"] %>
api_secret: <%= ENV["WEB_MERGE_API_SECRET"] %>
```

And it supports environment nesting (just like `database.yml`):

```yaml
development:
  api_key: "..."
  api_secret: "..."
production:
  api_key: "..."
  api_secret: "..."
```

### The `:path` option

To change the path of the file, use Paperclip's `:path` option:

```ruby
:path => ":style/:id_:filename"  # Defaults to ":filename"
```

### URL options

If you want to force the browser to always download the file, you can use
the `:download` option.

```ruby
user.document.url(:download => true)
```

### Check if the file exists

It may happen that a file on WebMerge gets deleted remotely. To check this in
your application, you can use the `#exists?` method:

```ruby
user.document.exists?
# user.document.exists?(style)
```

## Contributing

After checking out the repo, run `bundle install` to install dependencies. Then, run `rake spec` to run the tests.

Bug reports and pull requests are welcome on GitHub at https://github.com/plicjo/paperclip-webmerge.

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

